pub fn open_config<ObjectID: FsVerityHashValue>(
repo: &Repository<ObjectID>,
name: &str,
verity: Option<&ObjectID>,
) -> Result<(ImageConfiguration, DigestMap<ObjectID>)>Expand description
Opens and parses a container configuration, following all layer references.
Reads the OCI image configuration from the repository and returns both the parsed configuration and a digest map containing fs-verity hashes for all referenced layers. This performs a “deep” open that validates all layer references exist.
If verity is provided, it’s used directly. Otherwise, the name must be a sha256 digest and the corresponding verity hash will be looked up (which is more expensive).
Returns the parsed image configuration and the digest map of layer references.